Changes
=======

6.0 (2023-03-27)
----------------

- Add support for Python 3.11.

- Drop support for Python 3.6.


5.0 (2022-09-08)
----------------

- Add support for Python 3.8, 3.9, 3.10.

- Drop support for Python 2.7, 3.4, 3.5.


4.3 (2018-10-05)
----------------

- Add support for Python 3.7.

- Drop support for Python 3.3.


4.2 (2017-05-11)
----------------

- Add support for Python 3.5 and 3.6.

- Drop support for Python 2.6 and 3.2.

- 100% unit test coverage (including branches).

- Convert doctests to Sphinx documentation, including building docs
  and running doctest snippets under ``tox``.


4.1.0 (2014-12-26)
------------------

- Add support for PyPy3.

- Add support for Python 3.4.

- Add support for testing on Travis.


4.0.0 (2013-02-05)
------------------

- Made tests pass on Python 3.2, 3.3 and PyPy.

- Add support for continuous integration using ``tox``.

3.4.6 (2009-09-15)
------------------

- Make tests pass on python26.

3.4.5 (2009-01-27)
------------------

- Move README.txt in the egg, so tests works with the released egg as well.

3.4.4 (2009-01-27)
------------------

- Fix ReST in README.txt, fix broken tests with recent zope.testing.

3.4.3 (2008-12-02)
------------------

- More documentation and tests.

3.4.2 (2007-10-02)
------------------

- Fix broken release.

3.4.1 (2007-10-02)
------------------

- Update package meta-data.


3.4.0 (2007-07-19)
------------------

- Initial Zope-independent release.
